@@ -33,7 +33,7 @@
 
 #define SCM_ERROR_NOT_YET_IMPLEMENTED(what) \
   scm_c_gruntime_error (FUNC_NAME, "Not yet implemented: file ~S line ~S: ~A", \
-			SCM_LIST3 (scm_makfrom0str (__FILE__), SCM_MAKINUM (__LINE__), what))
+			SCM_LIST3 (scm_makfrom0str (__FILE__), scm_from_uint (__LINE__), what))
 
 
 
@@ -212,10 +212,17 @@ static void scm_c_gparam_initialize_scm (SCM param, gpointer ppspec)
                             : SCM_BOOL_F));
     }
     
-    /* borken! */
-    /* if (G_IS_PARAM_SPEC_UNICHAR (pspec)) */
-    else
+    else if (G_IS_PARAM_SPEC_UNICHAR (pspec)) {
+        GParamSpecUnichar *p = (GParamSpecUnichar *) pspec;
+        /* borken! */
+        SET (default_value, scm_from_uint (p->default_value));
+    }
+    
+    else {
+        g_warning ("param type not implemented: %s",
+                   g_type_name (G_TYPE_FROM_INSTANCE (pspec)));
         SCM_ERROR_NOT_YET_IMPLEMENTED (SCM_BOOL_F);
+    }
 
 #undef SET
 }
@@ -380,6 +387,11 @@ scm_c_gparam_construct (SCM instance, SCM initargs)
                                           (REF (element_spec), G_TYPE_PARAM),
                                           flags);
     }
+    else if (param_type == G_TYPE_PARAM_UNICHAR) {
+        pspec = g_param_spec_unichar (name, nick, blurb,
+                                      scm_to_uint (REF (default_value)),
+                                      flags);
+    }
     else {
         scm_c_gruntime_error ("%gparam-construct",
                               "Can't create instance of ~A from initargs: ~A",
