@@ -56,6 +56,10 @@ SCM scm_str2string (const char *src);
 #endif
 
 char* scm_to_locale_string_dynwind (SCM s);
+char* scm_symbol_chars (SCM s);
+char* scm_symbol_chars_dynwind (SCM s);
+char* scm_keyword_chars (SCM s);
+char* scm_keyword_chars_dynwind (SCM s);
 void scm_dynwind_guile_v__p_p (void* (*dynwind)(void*(*)(void*), void*), void *func,
                                void *arg1, void *arg2);
 void scm_dynwind_guile_v__p_u_p_p (void* (*dynwind)(void*(*)(void*), void*), void *func,
