@@ -59,6 +59,10 @@ GtkTreeIter* _wrap_gtk_list_store_insert_after (GtkListStore *store, GtkTreeIter
 GtkTreeIter* _wrap_gtk_list_store_prepend (GtkListStore *store);
 GtkTreeIter* _wrap_gtk_list_store_append (GtkListStore *store);
 
+void _wrap_gtk_menu_popup (GtkMenu *menu, GtkWidget *parent_menu_shell,
+                           GtkWidget *parent_menu_item, SCM func,
+                           guint button, guint32 activate_time);
+
 SCM _wrap_gtk_message_dialog_new (GtkWindow* parent, GtkDialogFlags flags, GtkMessageType type, GtkButtonsType buttons, const gchar *text);
 
 gchar* _gtk_selection_data_get_as_string (GtkSelectionData *data);
@@ -115,3 +119,4 @@ guint _wrap_gtk_ui_manager_add_ui_from_string (GtkUIManager *ui, const gchar *st
 GdkWindow* gtk_widget_get_window (GtkWidget *widget);
 GdkRectangle* gtk_widget_get_allocation (GtkWidget *widget);
 void _wrap_gtk_drag_dest_set (GtkWidget *widget, GtkDestDefaults flags, const GList *types, GdkDragAction actions);
+GtkStateType gtk_widget_get_state (GtkWidget *widget);
